Package: svglite
Title: An 'SVG' Graphics Device
Version: 2.2.2
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@posit.co", role = "aut"),
    person("Lionel", "Henry", , "lionel@posit.co", role = "aut"),
    person("Thomas Lin", "Pedersen", , "thomas.pedersen@posit.co", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-5147-4711")),
    person("T Jake", "Luciani", , "jake@apache.org", role = "aut"),
    person("Matthieu", "Decorde", , "matthieu.decorde@ens-lyon.fr", role = "aut"),
    person("Vaudor", "Lise", , "lise.vaudor@ens-lyon.fr", role = "aut"),
    person("Tony", "Plate", role = "ctb",
           comment = "Early line dashing code"),
    person("David", "Gohel", role = "ctb",
           comment = "Line dashing code and early raster code"),
    person("Yixuan", "Qiu", role = "ctb",
           comment = "Improved styles; polypath implementation"),
    person("Håkon", "Malmedal", role = "ctb",
           comment = "Opacity code"),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: A graphics device for R that produces 'Scalable Vector
    Graphics'. 'svglite' is a fork of the older 'RSvgDevice' package.
License: GPL (>= 2)
URL: https://svglite.r-lib.org, https://github.com/r-lib/svglite
BugReports: https://github.com/r-lib/svglite/issues
Depends: R (>= 4.1)
Imports: base64enc, cli, lifecycle, rlang (>= 1.1.0), systemfonts (>=
        1.3.0), textshaping (>= 0.3.0)
Suggests: covr, fontquiver (>= 0.2.0), htmltools, knitr, rmarkdown,
        testthat (>= 3.0.0), xml2 (>= 1.0.0)
LinkingTo: cpp11, systemfonts, textshaping
VignetteBuilder: knitr
Config/build/compilation-database: true
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-04-25
Encoding: UTF-8
RoxygenNote: 7.3.2
SystemRequirements: libpng
NeedsCompilation: yes
Packaged: 2025-10-20 15:57:25 UTC; thomas
Author: Hadley Wickham [aut],
  Lionel Henry [aut],
  Thomas Lin Pedersen [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-5147-4711>),
  T Jake Luciani [aut],
  Matthieu Decorde [aut],
  Vaudor Lise [aut],
  Tony Plate [ctb] (Early line dashing code),
  David Gohel [ctb] (Line dashing code and early raster code),
  Yixuan Qiu [ctb] (Improved styles; polypath implementation),
  Håkon Malmedal [ctb] (Opacity code),
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Thomas Lin Pedersen <thomas.pedersen@posit.co>
Repository: CRAN
Date/Publication: 2025-10-21 16:10:02 UTC
