# Generated by roxygen2: do not edit by hand

S3method(print,font_face)
S3method(print,svg)
export(add_fonts)
export(add_web_fonts)
export(create_svgz)
export(editSVG)
export(font_face)
export(font_feature)
export(fonts_as_import)
export(htmlSVG)
export(register_font)
export(register_variant)
export(require_font)
export(stringSVG)
export(svglite)
export(svgstring)
export(xmlSVG)
import(rlang)
importFrom(lifecycle,deprecated)
importFrom(systemfonts,add_fonts)
importFrom(systemfonts,font_feature)
importFrom(systemfonts,font_info)
importFrom(systemfonts,fonts_as_import)
importFrom(systemfonts,match_font)
importFrom(systemfonts,register_font)
importFrom(systemfonts,register_variant)
importFrom(systemfonts,require_font)
importFrom(textshaping,text_width)
useDynLib(svglite, .registration = TRUE)
