#' @importFrom systemfonts register_variant
#' @export
systemfonts::register_variant

#' @importFrom systemfonts register_font
#' @export
systemfonts::register_font

#' @importFrom systemfonts font_feature
#' @export
systemfonts::font_feature

#' @importFrom systemfonts fonts_as_import
#' @export
systemfonts::fonts_as_import

#' @importFrom systemfonts add_fonts
#' @export
systemfonts::add_fonts

#' @importFrom systemfonts require_font
#' @export
systemfonts::require_font
