# Generated by cpp11: do not edit by hand

svglite_ <- function(file, bg, width, height, pointsize, standalone, aliases, webfonts, id, fix_text_size, scaling, always_valid) {
  .Call(`_svglite_svglite_`, file, bg, width, height, pointsize, standalone, aliases, webfonts, id, fix_text_size, scaling, always_valid)
}

svgstring_ <- function(env, bg, width, height, pointsize, standalone, aliases, webfonts, id, fix_text_size, scaling) {
  .Call(`_svglite_svgstring_`, env, bg, width, height, pointsize, standalone, aliases, webfonts, id, fix_text_size, scaling)
}

get_svg_content <- function(p) {
  .Call(`_svglite_get_svg_content`, p)
}
